#! /bin/sh

#   Run this script when reconfiguring

aclocal-1.6
automake-1.6 -a
autoheader
autoconf

